==> PECL_Gen-0.8.1.tgz: PECL_Gen-0.8.1/Element/Test.php <==
<?php
//
// +----------------------------------------------------------------------+
// | PHP Version 5                                                        |
// +----------------------------------------------------------------------+
// | Copyright (c) 1997-2003 The PHP Group                                |
// +----------------------------------------------------------------------+
// | This source file is subject to version 3.0 of the PHP license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available at through the world-wide-web at                           |
// | http://www.php.net/license/3_0.txt.                                  |
// | If you did not receive a copy of the PHP license and are unable to   |
// | obtain it through the world-wide-web, please send a note to          |
// | license@php.net so we can mail you a copy immediately.               |
// +----------------------------------------------------------------------+
// | Authors: Hartmut Holzgraefe <hholzgra@php.net>                       |
// +----------------------------------------------------------------------+
//
// $Id: Test.php,v 1.3 2003/10/12 13:29:13 hholzgra Exp $
//

/**
 * Class for testfile generation as needed for 'make test'
 *
 * @access public
 */
class PECL_Gen_Element_Test
    extends PECL_Gen_Element
{
    /**
     * testfile basename
     *
     * @access private
     * @type   string
     */
    var $name = "";
    
    /** 
     * Constructor
     * 
     * @access public
     * @param  string  testfile basename
     */
    function __construct($name) 
    {
        if (! $this->is_name($name)) $this = $this->raise("'$name' is not a valid test case basename");

        $this->name = $name;
        $this->title = $name;
    }

    /**
     * Testcase description
     *
     * @access private
     * @type   string
     */
    var $title = "";

    /**
     * Getter for testcase title
     *
     * @access public
     * @return string  value of
     */
    function get_title() 
    {
        return $this->title;
    }
    
    /**
     * Setter for testcase title
     *
     * @access public
     * @param  string  new value for
     */
    function set_title($title) 
    {
        $this->title = $title;
    }
    
    /**
     * Test code to decide whether to skip a test
     *
     * @access private
     * @type   string
     */
    var $skipif = "";

    /**
     * Getter for skipif test code
     *
     * @access public
     * @return string  value of
     */
    function get_skipif() 
    {
        return $this->skipif;
    }
    
    /**
     * Setter for skipif testcode
     *
     * @access public
     * @param  string  new value for
     */
    function set_skipif($code) 
    {
        $this->skipif = $code;
    }
    
    /**
     * GET data
     *
     * @access private
     * @type   string
     */
    var $get = false;

    /**
     * Getter for GET data
     *
     * @access public
     * @return string  value of
     */
    function get_get() 
    {
        return $this->get;
    }
    
    /**
     * Setter for GET data
     *
     * @access public
     * @param  string  new value for
     */
    function set_get($data) 
    {
        $this->get = $data;
    }
    
    /**
     * raw POST data
     *
     * @access private
     * @type   string
     */
    var $post = false;

    /**
     * Getter for raw POST data
     *
     * @access public
     * @return string  value of
     */
    function get_post() 
    {
        return $this->post;
    }
    
    /**
     * Setter for raw POST data
     *
     * @access public
     * @param  string  new value for
     */
    function set_post($data) 
    {
        $this->post = $data;
    }
    
    /**
     * actual test code
     *
     * @access private
     * @type   string
     */

    /**
     * Getter for test code
     *
     * @access public
     * @return string  value of
     */
    function get_code() 
    {
        return $this->code;
    }
    
    /**
     * Setter for test code
     *
     * @access public
     * @param  string  new value for
     */
    function set_code($code) 
    {
        $this->code = $code;
    }
    
    /**
     * expected output for test code
     *
     * @access private
     * @type   string
     */

    /**
     * Getter for expected output
     *
     * @access public
     * @return string  value of
     */
    function get_output() 
    {
        return $this->output;
    }
    
    /**
     * Setter for expected output
     *
     * @access public
     * @param  string  new value for
     */
    function set_output($data) 
    {
        $this->output = $data;
    }

    /** 
     * all required properties set?
     *
     * @access public
     * @return bool
     */
    function complete() 
    {
        if (empty($this->code))   return $this->raiseError("no code specified for test case");
        if (empty($this->output)) return $this->raiseError("no output specified for test case");
        return true;
    }
    
    /**
     * generate testcase file
     *
     * @access public
     * @param  object  the complete extension context
     */
    function write_test($extension) 
    {
        ob_start();

        echo "--TEST--\n{$this->name}\n";
        
        if (!empty($this->skipif)) {
            echo "--SKIPIF--\n{$this->skipif}\n";
        }

        if (!empty($this->post)) {
            echo "--POST--\n{$this->post}\n";
        }

        if (!empty($this->get)) {
            echo "--GET--\n{$this->get}\n";
        }
        
        echo "--FILE--\n{$this->code}";
        echo "--EXPECT--\n{$this->output}";

        $fp = fopen("{$extension->name}/tests/{$this->name}.phpt", "w");
        fputs($fp, ob_get_contents());
        ob_end_clean();
        fclose($fp);
    }

    function c_code($ext) 
    { 
		// no real code is generated by the test cases
        return ""; 
    }

    function docbook_xml($ext) 
    { 
		// no user documentation is needed for the test cases
        return ""; 
    }
}
?>

==> PECL_Gen-0.8.5.tgz: PECL_Gen-0.8.5/Element/Test.php <==
<?php
//
// +----------------------------------------------------------------------+
// | PHP Version 5                                                        |
// +----------------------------------------------------------------------+
// | Copyright (c) 1997-2003 The PHP Group                                |
// +----------------------------------------------------------------------+
// | This source file is subject to version 3.0 of the PHP license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available at through the world-wide-web at                           |
// | http://www.php.net/license/3_0.txt.                                  |
// | If you did not receive a copy of the PHP license and are unable to   |
// | obtain it through the world-wide-web, please send a note to          |
// | license@php.net so we can mail you a copy immediately.               |
// +----------------------------------------------------------------------+
// | Authors: Hartmut Holzgraefe <hholzgra@php.net>                       |
// +----------------------------------------------------------------------+
//
// $Id: Test.php,v 1.1 2004/04/01 18:43:26 hholzgra Exp $
//

/**
 * Class for testfile generation as needed for 'make test'
 *
 * @access public
 */
class PECL_Gen_Element_Test
    extends PECL_Gen_Element
{
    /** 
     * Constructor
     * 
     * @access public
     * @param  string  testfile basename
     */
    function __construct() 
    {
    }

    /**
     * testfile basename
     *
     * @access private
     * @type   string
     */
    var $name = "";
    
    /**
     * Setter for testcase name
     *
     * @access public
     * @return string  value of
     */ function set_name($name) 
    {
        if (! $this->is_name($name)) {
            return $this->raise("'$name' is not a valid test case basename");
        }

        $this->name = $name;
        if (empty($this->title)) {
            $this->title = $name;   
        }
    }

    /**
     * Getter for testcase name
     *
     * @access public
     * @return string  value of
     */ 
    function get_name() 
    {
        return $this->name;
    }

    /**
     * Testcase description
     *
     * @access private
     * @type   string
     */
    var $title = "";

    /**
     * Getter for testcase title
     *
     * @access public
     * @return string  value of
     */
    function get_title() 
    {
        return $this->title;
    }
    
    /**
     * Setter for testcase title
     *
     * @access public
     * @param  string  new value for
     */
    function set_title($title) 
    {
        $this->title = $title;
    }
    
    /**
     * Test code to decide whether to skip a test
     *
     * @access private
     * @type   string
     */
    var $skipif = "";

    /**
     * Getter for skipif test code
     *
     * @access public
     * @return string  value of
     */
    function get_skipif() 
    {
        return $this->skipif;
    }
    
    /**
     * Setter for skipif testcode
     *
     * @access public
     * @param  string  new value for
     */
    function set_skipif($code) 
    {
        $this->skipif = $code;
    }
    
    /**
     * GET data
     *
     * @access private
     * @type   string
     */
    var $get = false;

    /**
     * Getter for GET data
     *
     * @access public
     * @return string  value of
     */
    function get_get() 
    {
        return $this->get;
    }
    
    /**
     * Setter for GET data
     *
     * @access public
     * @param  string  new value for
     */
    function set_get($data) 
    {
        $this->get = $data;
    }
    
    /**
     * raw POST data
     *
     * @access private
     * @type   string
     */
    var $post = false;

    /**
     * Getter for raw POST data
     *
     * @access public
     * @return string  value of
     */
    function get_post() 
    {
        return $this->post;
    }
    
    /**
     * Setter for raw POST data
     *
     * @access public
     * @param  string  new value for
     */
    function set_post($data) 
    {
        $this->post = $data;
    }
    
    /**
     * actual test code
     *
     * @access private
     * @type   string
     */

    /**
     * Getter for test code
     *
     * @access public
     * @return string  value of
     */
    function get_code() 
    {
        return $this->code;
    }
    
    /**
     * Setter for test code
     *
     * @access public
     * @param  string  new value for
     */
    function set_code($code) 
    {
        $this->code = $code;
    }
    
    /**
     * expected output for test code
     *
     * @access private
     * @type   string
     */

    /**
     * Getter for expected output
     *
     * @access public
     * @return string  value of
     */
    function get_output() 
    {
        return $this->output;
    }
    
    /**
     * Setter for expected output
     *
     * @access public
     * @param  string  new value for
     */
    function set_output($data) 
    {
        $this->output = $data;
    }

    /** 
     * all required properties set?
     *
     * @access public
     * @return bool
     */
    function complete() 
    {
        if (empty($this->code))   return $this->raiseError("no code specified for test case");
        if (empty($this->output)) return $this->raiseError("no output specified for test case");
        return true;
    }
    
    /**
     * generate testcase file
     *
     * @access public
     * @param  object  the complete extension context
     */
    function write_test($extension) 
    {
        ob_start();

        echo "--TEST--\n{$this->name}\n";
        
        if (!empty($this->skipif)) {
            echo "--SKIPIF--\n{$this->skipif}\n";
        }

        if (!empty($this->post)) {
            echo "--POST--\n{$this->post}\n";
        }

        if (!empty($this->get)) {
            echo "--GET--\n{$this->get}\n";
        }
        
        echo "--FILE--\n{$this->code}";
        echo "--EXPECT--\n{$this->output}";

        $fp = fopen("{$extension->name}/tests/{$this->name}.phpt", "w");
        fputs($fp, ob_get_contents());
        ob_end_clean();
        fclose($fp);
    }

    function c_code($ext) 
    { 
        // no real code is generated by the test cases
        return ""; 
    }

    function docbook_xml($ext) 
    { 
        // no user documentation is needed for the test cases
        return ""; 
    }
}
?>
